@@ -1005,7 +1005,7 @@ def perform_adjustment(
         
         guide_count_posterior_LFC_samples_normalized_list: List[List[float]] = shrinkage_result.guide_count_posterior_LFC_samples_normalized_list 
         
-        guide_count_posterior_LFC_samples_normalized_list_rescaled = np.asarray([np.exp(guide_count_posterior_LFC_samples_normalized_list) * ((each_guide.sample_population_normalized_count_reps[rep_i] + each_guide.control_population_normalized_count_reps[rep_i]) * negative_control_guide_control_population_total_normalized_counts_reps[rep_i]) / ((negative_control_guide_sample_population_total_normalized_counts_reps[rep_i] + negative_control_guide_control_population_total_normalized_counts_reps[rep_i]) * each_guide.control_population_normalized_count_reps[rep_i]) for rep_i in replicate_indices])
+        guide_count_posterior_LFC_samples_normalized_list_rescaled = np.asarray([np.exp(guide_count_posterior_LFC_samples_normalized_list[rep_i]) * ((each_guide.sample_population_normalized_count_reps[rep_i] + each_guide.control_population_normalized_count_reps[rep_i]) * negative_control_guide_control_population_total_normalized_counts_reps[rep_i]) / ((negative_control_guide_sample_population_total_normalized_counts_reps[rep_i] + negative_control_guide_control_population_total_normalized_counts_reps[rep_i]) * each_guide.control_population_normalized_count_reps[rep_i]) for rep_i in replicate_indices])
 
         guide_count_posterior_LFC_samples_normalized_average = np.mean(guide_count_posterior_LFC_samples_normalized_list, axis=0)
         guide_count_posterior_LFC_samples_normalized_rescaled_average =  np.mean(guide_count_posterior_LFC_samples_normalized_list_rescaled, axis=0)
@@ -1326,4 +1326,5 @@ if __name__ == "__main__":
         posterior_estimator = "mean",
         random_seed = 234,
         cores=10
-    ) # LEFTOFF - Fix Bug shown below
\ No newline at end of file
+    ) # LEFTOFF - Fix Bug shown below
+
